# Pytorch EO

Deep Learning for Earth Observation applications and research.

> 🚧 This project is in early development, so bugs and breaking changes are expected until we reach a stable version.

## Installation

```
pip install pytorch-eo
```

## Examples

Learn by doing with our [examples](https://github.com/earthpulse/pytorch_eo/tree/main/examples).

- [EuroSAT](examples/eurosat.ipynb).
- [UCMerced](examples/ucmerced.ipynb) Land Use Dataset.
- [BigEarthNet](examples/big_earth_net.ipynb).
- [SEN12FLOODs](examples/sen12floods.ipynb).

### Tutorials

Learn how to build with Pytorch EO with our [tutorials](https://github.com/earthpulse/pytorch_eo/tree/main/tutorials).

- Learn about [data loading](tutorials/00_data_loading.ipynb) is Pytorch EO.
- Learn about [data augmentation](tutorials/00_data_augmentation.ipynb) is Pytorch EO.
- Learn how to [create datasets](tutorials/02_creating_datasets.ipynb) with Pytorch EO.
- Learn about training models with our [tasks](tutorials/03_tasks.ipynb).

## Challenges

PytorchEO has been used in the following challenges:

- [EUROAVIA](./challenges/euroavia_hackathon_21) Mission: European Students Space Hackathon, 2021.
- [On Cloud N](./challenges/OnCloudN): Cloud Cover Detection Challenge (DrivenData, 2021).

<!-- ### Build your own Datasets

Using SCAN you can annotate your own data and access it directly through Pytorch EO. -->

<!-- ## Research

Pytorch EO can be a useful tool for research:

- Flexibility: build and experiment with new models for EO applications.
- Reproducibility: use same data splits and random seeds to compare with others.

See the [examples](https://github.com/earthpulse/pytorch_eo/tree/main/examples).

## Production

Pytorch EO was built with production in mind from the beginning:

- Optimize model for production.
- Export models to torchscript.
- Upload models to our Models Universe
- Use models directly through SPAI

See the [examples](https://github.com/earthpulse/pytorch_eo/tree/main/examples). -->

<!-- ## Documentation

Read our [docs](https://earthpulse.github.io/pytorch_eo/). -->

## Contributing

Read the [CONTRIBUTING](https://github.com/earthpulse/pytorch_eo/blob/main/CONTRIBUTING.md) guide.
